function ErrorCode = DBCreateQuery(DB, QueryName, SQLQuery);
% DBCreateQuery   Creates a permanent query (without getting data)
%
% ErrorCode = DBCreateQuery(DB, QueryName, SQLQuery);
%
% DB is obtained with DBOpen.
% QueryName is a string.
% SQLQuery is a SELECT-SQL query, a string.
%
% ErrorCode is zero for successful completion. After completion, the query
% "QueryName" can be used as a normal Table. It is negative if
% unsuccessful.
%
% (c) 2003, CSE; see library header for more information.

ErrorCode = 0;

if strcmp(SQLQuery(1:6), 'SELECT')
	if strcmp(class(DB), 'activex')
        try
            invoke(DB, 'CreateQueryDef', QueryName, SQLQuery);
        catch
            ErrorCode = -1;
            blop = lasterr;
            warning(sprintf('CSE DB Library Error (Compatibility Mode)\nUnable to execute query definition:\n%s', blop));
        end
	else
		try
            DB.CreateQueryDef(QueryName, SQLQuery);
		catch
            ErrorCode = -1;
            blop = lasterr;
            warning('CSE:DBLibrary', ['CSE DB Library Error\nUnable to execute query definition:\n%s'], blop);
		end
    end
else
    ErrorCode = -1;
    if strcmp(class(DB), 'activex')
        warning(sprintf('CSE DB Library Error (Compatibility Mode)\nQuery must begin with ''SELECT''. Invalid query:\n%s', SQLQuery));
    else
        warning('CSE:DBLibrary', ['CSE DB Library Error\nQuery must begin with ''SELECT''. Invalid query:\n%s'], SQLQuery);
    end
end

