function ErrorCode = DBDeleteQuery(DB, QueryName);
% DBDeleteQuery   Deletes a permanent query (without getting data)
%
% ErrorCode = DBDeleteQuery(DB, QueryName);
%
% DB is obtained with DBOpen.
% QueryName is a string.
%
% ErrorCode is zero for successful completion. After completion, the query
% "QueryName" is destroyed - the underlying data remains of course available.
% It is negative if unsuccessful.
%
% WARNING: This function can also be used to delete tables. Take care, as if
% you delete tables, the underlying data will be irremediably destroyed.
% No control is done that it is indeed a query you are deleting...
%
% (c) 2003, CSE; see library header for more information.

ErrorCode = 0;

if strcmp(class(DB), 'activex')
    try
        invoke(DB, 'Execute', ['DROP TABLE ' QueryName]);
    catch
        ErrorCode = -1;
        blop = lasterr;
        warning(sprintf('CSE DB Library Error (Compatibility Mode)\nUnable to delete query definition:\n%s', blop));
    end
else
	try
        DB.Execute(['DROP TABLE ' QueryName]);
	catch
        ErrorCode = -1;
        blop = lasterr;
        warning('CSE:DBLibrary', ['CSE DB Library Error\nUnable to delete query definition:\n%s'], blop);
	end
end