function DB = DBOpen(SQLServer, DBName);
% DBOpen    Open an SQL database
%
% DB = DBOpen(SQLServer, DBName);
%
% Open an SQL database based on the partial or full path DBName.
% SQLServer is obtained with DBInitialize.
%
% DO NOT USE: db = DBOpen(DBInitialize, 'C:\blah\myDB.ips');
% An explicit output argument must be used for DBInitialize.
%
% Multiple databases can be open at the same time on the same server.
%
% See also DBINITIALIZE and other library functions
%
% Compatibility mode: Only one database per Server.
%
% (c) 2003, CSE; see library header for more information.

if strcmp(class(SQLServer), 'COM.access.application')
    try
        DB = SQLServer.DBEngine.OpenDatabase(DBName);
    catch
        blop = lasterr;
        error('CSE:DBLibrary', ['CSE DB Library Error\nUnable to open database:\n%s'], blop);
    end
elseif SQLServer == -1 % strcmp(class(SQLServer), 'activex')
    % we are in compatibility mode, only one DB can be open at a time, so let's
    % close if one is still open!
    %try
        DBClose(SQLServer, []);
        assignin('base', 'DBName', DBName);
        evalin('base', 'invoke(SQLServer, ''OpenCurrentDatabase'', DBName); clear DBName;');
        evalin('base', 'DB = invoke(SQLServer, ''CurrentDB'');');
        DB = -1;
        %catch
        %blop = lasterr;
        %error(sprintf('CSE DB Library Error (Compatibility Mode)\nUnable to open database:\n%s', blop));
        % end
else
    error('CSE:DBLibrary', 'CSE DB Library Fatal Error\nThe server object passed in argument is not valid.\nIt is of class "%s" instead of "COM.access.application".', class(SQLServer));
end