function DataTable = DBQuery(DB, SQLQuery, varargin);
% DBQuery   Execute a query and get resulting data from an SQL database
%
% DataTable = DBQuery(DB, SQLQuery);
% DataTable = DBQuery(DB, SQLQuery, format);
%
% SQLQuery is a SELECT-SQL query, a string. It must begin with 'SELECT'.
% DB is obtained with DBOpen.
% format is either 'All' or 'Numeric'. If format is 'All' (default), the
% return element DataTable is a cell array. If format is 'Numeric', the
% return element is a matrix and non-numeric columns (if any) are dropped.
%
% (c) 2003, CSE; see library header for more information.

if nargin < 3
    formatstr = 'All';
else
    formatstr = varargin{1};
end
            
if strcmp(SQLQuery(1:6), 'SELECT')
	if DB == -1  %strcmp(class(DB), 'activex')
        try
            assignin('base', 'SQLQuery', SQLQuery);
            evalin('base', 'tmp_data = invoke(DB, ''OpenRecordset'', SQLQuery);');
            tmp_DataTable = evalin('base', 'invoke(tmp_data, ''GetRows'', 32000)'';', '[]');
            evalin('base', 'invoke(tmp_data, ''Close''); clear tmp_data; clear SQLQuery;');
        catch
            tmp_DataTable = [];
            blop = lasterr;
            if ~strcmp(blop(1:4), 'No c')
                warning(sprintf('CSE DB Library Error (Compatibility Mode)\nUnable to execute and read query:\n%s', blop));
%                 evalin('base', 'tmp = get(invoke(SQLServer, ''CurrentDb''), ''Name'');');
%                 evalin('base', 'invoke(SQLServer, ''CloseCurrentDatabase'');');
% 				evalin('base', 'invoke(SQLServer, ''Quit'')');
% 				evalin('base', 'release(SQLServer);');
% 				evalin('base', 'delete(SQLServer);');
%                 evalin('base', 'clear global SQLServer;');
%                 DBInitializeR12;
%                 evalin('base', 'invoke(SQLServer, ''OpenCurrentDatabase'', tmp); clear tmp;');
            end
        end
	else
		try
            tmp_data = DB.OpenRecordset(SQLQuery);
            if ~get(tmp_data, 'EOF')
                % we are not at end of file, i.e. it is not empty
                tmp_DataTable = tmp_data.GetRows(32000)';
            else
                DataTable = [];
                return;
            end
		catch
            blop = lasterr;
            warning('CSE:DBLibrary', ['CSE DB Library Error\nUnable to execute and read query:\n%s'], blop);
            DataTable = [];
            return;
		end
    end
	
	if strcmpi(formatstr, 'Numeric')
        DataTable = [];
        for i = 1:size(tmp_DataTable,1)
            for j = 1:size(tmp_DataTable,2)
                if isnumeric(tmp_DataTable{i, j})
                    DataTable(i, j) = tmp_DataTable{i, j};
                end
            end
        end
	else
        DataTable = tmp_DataTable;
	end
else
    DataTable = [];
    if strcmp(class(DB), 'activex')
        warning(sprintf('CSE DB Library Error (Compatibility Mode)\nQuery must begin with ''SELECT''. Invalid query:\n%s', SQLQuery));
    else
        warning('CSE:DBLibrary', ['CSE DB Library Error\nQuery must begin with ''SELECT''. Invalid query:\n%s'], SQLQuery);
    end
end