function DataTable = DBRead(DB, TableName, varargin);
% DBRead    Read a Table from an SQL database
%
% DataTable = DBRead(DB, TableName);
% DataTable = DBRead(DB, TableName, format);
%
% TableName is a string.
% DB is obtained with DBOpen.
% format is either 'All' or 'Numeric'. If format is 'All' (default), the
% return element DataTable is a cell array. If format is 'Numeric', the
% return element is a matrix and non-numeric columns (if any) are dropped.
%
% (c) 2003, CSE; see library header for more information.

if nargin < 3
    formatstr = 'All';
else
    formatstr = varargin{1};
end

if DB == -1 % strcmp(class(DB), 'activex')
    try
        evalin('base', 'tmp_data = invoke(DB, ''OpenRecordset'', TableName);');
        tmp_DataTable = evalin('base', 'invoke(tmp_data, ''GetRows'', 32000)'';', '[]');
        evalin('base', 'invoke(tmp_data, ''Close''); clear tmp_data;');
    catch
        tmp_DataTable = [];
        blop = lasterr;
        warning(sprintf('CSE DB Library Error (Compatibility Mode)\nUnable to read table:\n%s', blop));
    end

else
	try
        tmp_data = DB.OpenRecordset(['SELECT * FROM ' TableName ';']);
        tmp_DataTable = tmp_data.GetRows(32000)';
	catch
        tmp_DataTable = [];
        blop = lasterr;
        warning('CSE:DBLibrary', ['CSE DB Library Error\nUnable to read table:\n%s'], blop);
	end
end
	
if strcmpi(formatstr, 'Numeric')
    for i = 1:size(tmp_DataTable,1)
        for j = 1:size(tmp_DataTable,2)
            if isnumeric(tmp_DataTable{i, j})
                DataTable(i, j) = tmp_DataTable{i, j};
            end
        end
    end
else
    DataTable = tmp_DataTable;
end