function TableDef = DBTableDef(DB, TableName);
% DBTableDef    Analyze Table from an SQL database
%
% TableDef = DBTableDef(DB, TableName);
%
% TableName is a string.
% DB is obtained with DBOpen.
%
% TableDef contains the fields
%   columns = number of columns
%   records = number of records in table
%   TypeN(:) = type of the different columns (coded, see below)
%   Type(:) = type of the different columns (3 char text, see below)
%
%     TypeN Type Explanation:
%     -----------------------
%       0   ???  Unknown
%       1   INT  integer
%       2   NUM  numeric (float)
%       3   TXT  text
%       4   LOG  logical
%
% Note: ??? will result for each field containing NaN
%       i.e. all empty fields of the first record.
%
% (c) 2003, CSE; see library header for more information.

if strcmp(class(DB), 'activex')
    try
        tmp_data = invoke(DB, 'OpenRecordset', ['SELECT * FROM ' TableName ';']);
        tmp_DataTable = invoke(tmp_data, 'GetRows', 1)';
        invoke(tmp_data, 'Close');
    catch
        ErrorCode = -1;
        blop = lasterr;
        warning(sprintf('CSE DB Library Error (compatibility mode)\nUnable to access table:\n%s', blop));
    end
else
	try
        tmp_data = DB.OpenRecordset(['SELECT * FROM ' TableName ';']);
        tmp_DataTable = tmp_data.GetRows(1)';
	catch
        tmp_DataTable = [];
        blop = lasterr;
        warning('CSE:DBLibrary', ['CSE DB Library Error\nUnable to access table:\n%s'], blop);
	end
end

TableDef.columns = size(tmp_DataTable,2);
TableDef.records = size(tmp_DataTable,1);

for j = 1:size(tmp_DataTable,2)
    if isnumeric(tmp_DataTable{1, j})
        if isnan(double(tmp_DataTable{1, j}))
            TableDef.Type(j,:) = '???';
            TableDef.TypeN(j) = 0;
        else
            if ~isempty(findstr(class(tmp_DataTable{1, j}), 'int'))
                TableDef.Type(j,:) = 'INT';
                TableDef.TypeN(j) = 1;
            else
                TableDef.Type(j,:) = 'NUM';
                TableDef.TypeN(j) = 2;
            end
        end
    elseif islogical(tmp_DataTable{1, j})
        TableDef.Type(j,:) = 'LOG';
        TableDef.TypeN(j) = 4;
    elseif ischar(tmp_DataTable{1, j})
        TableDef.Type(j,:) = 'TXT';
        TableDef.TypeN(j) = 3;
    else
        TableDef.Type(j,:) = '???';
        TableDef.TypeN(j) = 0;
    end
end
    